clear
clear matrix
clear mata

set maxvar 120000

do "$root/Analyses/aux/set_globals"
use "$root/Data/survey_analysis_final.dta", clear

***********************************************************************************
* Figure 10: Benchmarking with variables (incl. interactions of other variables) selected
* by LASSO as predictive of summary statistic
***********************************************************************************

drop if inlist(country, "Korea", "Brazil")

* Regress on all interactions of variables
global features c.s_age##c.s_religion_index##c.s_income_index##c.s_wealth_index##c.s_male##c.s_college##c.s_neighborhood_size_0to9##c.s_res_altruism##c.s_res_trust##c.s_inefficiency_equity##c.s_govt_wasteful0_efficient_10

qui lasso linear left_right $features i.country_no

* Coefficients from OLS regression with variables selected by LASSO
lassocoef, display(coef, postselection) sort(coef, postselection)
	
* Select top 10 variables (other than country FEs, and including universalism)
* by absolute value of coefficient
global clusters s_universalism_overall s_religion_index s_wealth_index s_college ///
s_res_trust c.s_inefficiency_equity#c.s_govt_wasteful0_efficient_10 ///
c.s_age#c.s_govt_wasteful0_efficient_10 c.s_income_index#c.s_govt_wasteful0_efficient_10 ///
s_income_index c.s_male#c.s_govt_wasteful0_efficient_10 s_male

graph drop _all

*******************************************************************************
* Figure 10: Benchmarking
*******************************************************************************

preserve

* Generate new empty observations simply to store coefficients and standard errors
* for each individual profile / variable
set obs 14742

gen cluster="s_universalism_overall" in 14732
replace cluster="s_religion_index" in 14733
replace cluster="s_wealth_index" in 14734
replace cluster="s_college" in 14735
replace cluster="s_res_trust" in 14736
replace cluster="c.s_inefficiency_equity#c.s_govt_wasteful0_efficient_10" in 14737
replace cluster="c.s_age#c.s_govt_wasteful0_efficient_10" in 14738
replace cluster="c.s_income_index#c.s_govt_wasteful0_efficient_10" in 14739
replace cluster="s_income_index" in 14740
replace cluster="c.s_male#c.s_govt_wasteful0_efficient_10" in 14741
replace cluster="s_male" in 14742

* Regress, get coefficients
foreach i in $policies {

	gen b_`i'=.
	gen se_`i'=.
	
	* Predictors
	foreach pref in $clusters {
		
		qui areg s_hs_`i'_budget `pref', absorb(country) vce(robust)

		replace b_`i'=_b[`pref'] if cluster=="`pref'"
		replace se_`i'=_se[`pref'] if cluster=="`pref'"
	
	}
}

keep b_* se_* cluster
collapse b_* se_*, by(cluster)
drop if cluster==""

reshape long b_ se_, i(cluster) j(domain, string)

rename *_ *

gen upper=b+1.96*se
gen lower=b-1.96*se

replace cluster="Composite Universalism" if cluster=="s_universalism_overall"
replace cluster="Religiosity" if cluster=="s_religion_index"
replace cluster="Wealth" if cluster=="s_wealth_index"
replace cluster="College" if cluster=="s_college"
replace cluster="Residual Trust" if cluster=="s_res_trust"
replace cluster="Inefficiency x Gov't Efficient" if cluster=="c.s_inefficiency_equity#c.s_govt_wasteful0_efficient_10"
replace cluster="Age x Gov't Efficient" if cluster=="c.s_age#c.s_govt_wasteful0_efficient_10"
replace cluster="Income x Gov't Efficient" if cluster=="c.s_income_index#c.s_govt_wasteful0_efficient_10"
replace cluster="Income" if cluster=="s_income_index"
replace cluster="Male x Gov't Efficient" if cluster=="c.s_male#c.s_govt_wasteful0_efficient_10"
replace cluster="Male" if cluster=="s_male"

*******************************************************************************
* Figure 10: Benchmarking
*******************************************************************************

* encoding in a specific order

gen outcome_no = 1 if cluster == "Composite Universalism"
replace outcome_no = 2 if cluster == "Religiosity"
replace outcome_no = 3 if cluster == "Wealth"
replace outcome_no = 4 if cluster == "Residual Trust"
replace outcome_no = 5 if cluster == "College"
replace outcome_no = 6 if cluster == "Inefficiency x Gov't Efficient"
replace outcome_no = 7 if cluster == "Age x Gov't Efficient"
replace outcome_no = 8 if cluster == "Income x Gov't Efficient"
replace outcome_no = 9 if cluster == "Income"
replace outcome_no = 10 if cluster == "Male x Gov't Efficient"
replace outcome_no = 11 if cluster == "Male"

gen outcome_jitter = outcome_no-0.225 if domain=="border"
replace outcome_jitter = outcome_no-0.15 if domain=="military"
replace outcome_jitter = outcome_no-0.075 if domain=="police"
replace outcome_jitter = outcome_no if domain=="foreignaid"
replace outcome_jitter = outcome_no+0.075 if domain=="affaction"
replace outcome_jitter = outcome_no+0.15 if domain=="environment"
replace outcome_jitter = outcome_no+0.225 if domain=="health"
replace outcome_jitter = outcome_no+0.3 if domain=="welfare"

graph drop _all

* Preferences and Beliefs
tw (scatter b outcome_jitter if domain=="border", msymbol(triangle) msize(vsmall) mcolor(black)) ///
	(scatter b outcome_jitter if domain=="military", msymbol(triangle) msize(vsmall) mcolor(blue)) ///
	(scatter b outcome_jitter if domain=="police", msymbol(triangle) msize(vsmall) mcolor(lavender)) ///
	(scatter b outcome_jitter if domain=="foreignaid", msymbol(square) msize(vsmall) mcolor(ebblue)) ///
	(scatter b outcome_jitter if domain=="affaction", msymbol(square) msize(vsmall) mcolor(navy)) ///
	(scatter b outcome_jitter if domain=="environment", msymbol(square) msize(vsmall) mcolor(midgreen)) ///
	(scatter b outcome_jitter if domain=="health", msymbol(square) msize(vsmall) mcolor(dkorange)) ///
	(scatter b outcome_jitter if domain=="welfare", msymbol(square) msize(vsmall) mcolor(maroon)) ///
	(rcap lower upper outcome_jitter if domain=="border", msize(vtiny) lcolor(black)) ///
	(rcap lower upper outcome_jitter if domain=="military", msize(vtiny) lcolor(blue)) ///
	(rcap lower upper outcome_jitter if domain=="police", msize(vtiny) lcolor(lavender)) ///
	(rcap lower upper outcome_jitter if domain=="foreignaid", msize(vtiny) lcolor(ebblue)) ///
	(rcap lower upper outcome_jitter if domain=="affaction", msize(vtiny) lcolor(navy)) ///
	(rcap lower upper outcome_jitter if domain=="environment", msize(vtiny) lcolor(midgreen)) ///
	(rcap lower upper outcome_jitter if domain=="health", msize(vtiny) lcolor(dkorange)) ///
	(rcap lower upper outcome_jitter if domain=="welfare", msize(vtiny) lcolor(maroon)) ///
	, ///
	xlabel(1 `" "Composite" "Universalism" "' 2 "Religiosity" 3 "Wealth" 4 `" "Residual" "Trust" "' ///
	5 "College" 6 "E x G" 7 "Age x G" 8 "Income x G" 9 "Income" 10 "Male x G" 11 "Male", ///
	labsize(vsmall) notick) ///
	ylabel(-0.1(0.05)0.2, labsize(small)) ///
	legend(order(1 "Border" 2 "Military" 3 "Police" 4 "Foreign Aid" 5 "Affirmative Action" ///
		6 "Environment" 7 "Health" 8 "Welfare") ///
	size(small) cols(4)) xtitle("") graphregion(color(white)) ///
	yline(0, lcolor(black) lwidth(vthin)) xscale(r(0.5 10.5) noline) yscale(r(-0.1 0.2) noline) ///
	xline(1.5 2.5 3.5 4.5 5.5 6.5 7.5 8.5 9.5 10.5, lpattern(dot) lcolor(black)) ///
	title("Regression: Desired Arsinh Expenditure Levels on Individual Profiles", size(medium)) ///
	ytitle("Regression coefficient", size(medsmall) height(4.5)) ///
	note("Includes Country Fixed Effects; {bf: Key}: E: Efficiency-Equity Preferences; G: Gov't Wasteful vs. Efficient") xsize(6) name(benchmarking)

graph display benchmarking, xsize(6.5)

graph export "$root/Output/fig_10_benchmarking_clusters.eps", replace

restore
