***********************************************************************************
* FIGURE 1
* PCA OF 8 POLICY POSITIONS, AS MEASURED BY EXPENDITURE SHARES
***********************************************************************************
do "$root/Analyses/aux/set_globals"
use "$root/Data/survey_analysis_final.dta", clear

* Redefining the "policies" global to use expenditure shares
global policies "s_border_portion s_military_portion s_police_portion s_foreignaid_portion s_affaction_portion s_environment_portion s_health_portion s_welfare_portion"

preserve
graph drop _all

* Generating loadings
foreach j in $policies{
	gen `j'_load = .
}

foreach i in $countries_western{
	pca $policies if country=="`i'"
	mat loadings = e(L)
	
	* For consistency, make it so that "border" has a negative sign for all countries
	if loadings[1, 1] > 0 {
		mat loadings = -1*loadings
	}
	
	foreach j in $policies{
		mat load = loadings["`j'", 1]
		scalar load2 = load[1,1]
		replace `j'_load = load2 if country=="`i'"
		
	}
}

collapse (mean) *_load, by(country)
sort country
xpose, clear v
drop if _varname == "country"

rename (v1 v3 v4 v6 v7 _varname) ///
		(Australia France Germany Sweden USA loading)

* Drop non-Western countries
drop v2 v5		
		
* encoding in a specific order
gen loading_no = 1 if strpos(loading, "border")
replace loading_no = 2 if strpos(loading, "military")
replace loading_no = 3 if strpos(loading, "police")
replace loading_no = 4 if strpos(loading, "foreignaid")
replace loading_no = 5 if strpos(loading, "affaction")
replace loading_no = 6 if strpos(loading, "environment")
replace loading_no = 7 if strpos(loading, "health")
replace loading_no = 8 if strpos(loading, "welfare")

label define policy_lab 1 "Border" 2 "Military" 3 "Police" 4 "Foreign Aid" ///
						5 "Affirmative Action" 6 "Environment" 7 `" "Health" "Care" "' 8 "Welfare"
label values loading_no policy_lab

gen loading_jitter1 = loading_no-0.15
gen loading_jitter2 = loading_no+0.15

gen loading_jitter1_panelB = loading_no-0.2
gen loading_jitter2_panelB = loading_no+0.2

**********************************
* Figure 1
**********************************
tw (scatter France loading_no, ///
	msymbol(square) ///
	mcolor(navy) msize(medium medium medium) mlwidth(thick)) ///
	(scatter Germany USA loading_jitter1, ///
	msymbol(triangle circle) ///
	mcolor(ebblue blue) msize(medium medium medium) mlwidth(thick thick thick)) ///
	(scatter Australia Sweden loading_jitter2, ///
	msymbol(diamond plus) ///
	mcolor(lavender midgreen) msize(medium medium medium) mlwidth(thick thick thick)), ///
	xlabel(1 "Border" 2 "Military" 3 "Police" 4 `" "Foreign" "Aid" "' ///
	5 `" "Affirmative" "Action" "' 6 `" "Environ-" "ment" "' 7 `" "Health" "Care" "' 8 "Welfare", ///
	labsize(medlarge) notick) ///
	ylabel(, labsize(medlarge)) ///
	legend(order(3 "USA" 4 "Australia" 2 "Germany" 1 "France" 5 "Sweden") ///
	size(medlarge) cols(5)) xtitle("") graphregion(color(white)) ///
	ytitle("Loading of first principal component", size(medlarge)) ///
	xline(1.5 2.5 3.5 4.5 5.5 6.5 7.5, lpattern(dot) lcolor(black)) ///
	yline(0, lcolor(black)) xscale(r(0.5 8.5) noline) yscale(noline) ///
	title("First eigenvector of desired expenditure shares", size(vlarge))
	
graph display, xsize(8) ysize(4)

graph export "$root/Output/fig_1_clusters.eps", replace
