do "$root/Analyses/aux/set_globals"
use "$root/Data/survey_analysis_final.dta", clear

graph drop _all

***********************************************************************************
* Figure 5: Binscatters of composite universalism and left-wing ideology
***********************************************************************************

preserve

drop if inlist(country, "Korea", "Brazil")

* Manually residualize of country FEs
reg left_right i.country_no
predict left_right_resid, resid

summarize left_right
replace left_right_resid=left_right_resid+r(mean)

reg universalism_overall i.country_no
predict universalism_overall_resid, resid

summarize universalism_overall
replace universalism_overall_resid=universalism_overall_resid+r(mean)

binscatter left_right_resid universalism_overall_resid if country=="France" | country=="Germany" | country=="Sweden", by(country) ///
graphregion(color(white)) ///
nquant(15) title("Self-reported left-wing ideology and universalism: Europe", color(black) size(medlarge)) ///
ytitle("Left-wing ideology (0-10)", size(medium)) xtitle("Composite Universalism", size(medium)) ///
colors(navy ebblue midgreen) ///
yscale(r(3 6)) ylabel(3(1)6, labsize(small)) ///
legend(order(1 "France" 2 "Germany" 3 "Sweden") ///
size(medlarge) cols(6) symxsize(8)) msymbols(square triangle plus)

graph export "$root/Output/fig_5_binscatter_univ_Europe.eps", replace

binscatter left_right_resid universalism_overall_resid if country=="Australia" | country=="USA", by(country) ///
graphregion(color(white)) ///
nquant(15) title("Self-reported left-wing ideology and universalism: Non-Europe", color(black) size(medlarge)) ///
ytitle("Left-wing ideology (0-10)", size(medium)) xtitle("Composite Universalism", size(medium)) ///
colors(lavender blue) ///
legend(order(1 "Australia" 2 "USA") ///
size(medlarge) cols(6) symxsize(8)) msymbols(diamond circle)

graph export "$root/Output/fig_5_binscatter_univ_nonEurope.eps", replace

restore
