* FIGURES THAT PLOT REGRESSION COEFFICIENTS
do "$root/Analyses/aux/set_globals"
use "$root/Data/survey_analysis_final.dta", clear

graph drop _all

***********************************************************************************
* Figure 6: Coefs from regressions of policy positions on universalism - WITH CONTROLS
* WITH LIKERT SCALE QUESTIONS
***********************************************************************************
preserve

drop if inlist(country, "Korea", "Brazil")

* Generate two observation for "All countries", in order to produce the
* shaded areas in figures
local new = _N + 1
set obs `new'
replace country = "Overall" if country == ""

local new = _N + 1
set obs `new'
replace country = "Overall2" if country == ""

foreach j in $policies{
	gen beta_`j' = .
	gen se_`j' = .
}

**********************************
* Running regressions
**********************************
foreach j in $policies{
	foreach i in $countries_western{
		qui reg s_`j'_rel_support universalism_overall $controls `j'_belief_benefit if country=="`i'", ro
		mat bet = e(b)
		mat cov = e(V)
		
		replace beta_`j' = bet[1,1] if country == "`i'"
		replace se_`j' = sqrt(cov[1,1]) if country == "`i'"
	}
	
	* All countries	
	qui reg s_`j'_rel_support universalism_overall $controls `j'_belief_benefit i.country_no, ro
	mat bet = e(b)
	mat cov = e(V)
	
	replace beta_`j' = bet[1,1] if country == "Overall" | country=="Overall2"
	replace se_`j' = sqrt(cov[1,1]) if country == "Overall" | country=="Overall2"
	
	gen bmin_`j' = beta_`j' - 1.96*se_`j'
	gen bmax_`j' = beta_`j' + 1.96*se_`j'
}

collapse (mean) beta_* se_* bmin_* bmax_*, by(country)
reshape long beta se bmin bmax, i(country) j(domain) string
replace domain = subinstr(domain, "_", "", 1)

* encoding in a specific order
gen domain_no = 1 if domain == "border"
replace domain_no = 2 if domain == "military"
replace domain_no = 3 if domain == "police"
replace domain_no = 4 if domain == "foreignaid"
replace domain_no = 5 if domain == "affaction"
replace domain_no = 6 if domain == "environment"
replace domain_no = 7 if domain == "health"
replace domain_no = 8 if domain == "welfare"

gen domain_jitter = domain_no-0.5 if country=="Overall"
replace domain_jitter=domain_no+0.49 if country=="Overall2"

replace domain_jitter = domain_no-0.2 if country=="USA"
replace domain_jitter = domain_no-0.1 if country=="Australia"
replace domain_jitter = domain_no if country=="Germany"
replace domain_jitter = domain_no+0.1 if country=="France"
replace domain_jitter = domain_no+0.2 if country=="Sweden"

*Rename Overall2 to Overall for proper formatting of shaded areas
replace country="Overall" if country=="Overall2"

**********************************
* Figure 6: Expenditure Shares on Universalism (Panel D)
**********************************
	
tw (scatter beta domain_jitter if country=="USA", msymbol(circle) msize(small) mcolor(blue)) ///
	(scatter beta domain_jitter if country=="Australia", msymbol(diamond) msize(small) mcolor(lavender)) ///
	(scatter beta domain_jitter if country=="Germany", msymbol(triangle) msize(small) mcolor(ebblue)) ///
	(scatter beta domain_jitter if country=="France", msymbol(square) msize(small) mcolor(navy)) ///
	(scatter beta domain_jitter if country=="Sweden", msymbol(plus) msize(small) mcolor(midgreen)) ///
	(line beta domain_jitter if country=="Overall" & domain=="affaction", lcolor(black%40) sort) ///
	(line beta domain_jitter if country=="Overall" & domain=="border", lcolor(black%40) sort) ///
	(line beta domain_jitter if country=="Overall" & domain=="environment", lcolor(black%40) sort) ///
	(line beta domain_jitter if country=="Overall" & domain=="foreignaid", lcolor(black%40) sort) ///
	(line beta domain_jitter if country=="Overall" & domain=="health", lcolor(black%40) sort) ///
	(line beta domain_jitter if country=="Overall" & domain=="military", lcolor(black%40) sort) ///
	(line beta domain_jitter if country=="Overall" & domain=="police", lcolor(black%40) sort) ///
	(line beta domain_jitter if country=="Overall" & domain=="welfare", lcolor(black%40) sort) ///
	(rarea bmin bmax domain_jitter if country=="Overall", sort lwidth(none) fcolor(gray%40)) ///
	(rcap bmin bmax domain_jitter if country=="USA", sort msize(vtiny) lcolor(blue)) ///
	(rcap bmin bmax domain_jitter if country=="Australia", sort msize(vtiny) lcolor(lavender)) ///
	(rcap bmin bmax domain_jitter if country=="Germany", sort msize(vtiny) lcolor(ebblue)) ///
	(rcap bmin bmax domain_jitter if country=="France", sort msize(vtiny) lcolor(navy)) ///
	(rcap bmin bmax domain_jitter if country=="Sweden", sort msize(vtiny) lcolor(midgreen)), ///
	xlabel(1 "Border" 2 "Military" 3 "Police" 4 `" "Foreign" "Aid" "' ///
	5 `" "Affirmative" "Action" "' 6 `" "Environ-" "ment" "' 7 `" "Health" "Care" "' 8 "Welfare", ///
	labsize(medium) notick) ///
	ylabel(-3(1)3, labsize(medium)) ///
	legend(order(1 "USA" 2 "Australia" 3 "Germany" 4 "France" 5 "Sweden" 6 "All countries") ///
	size(medium) cols(6) symxsize(8)) xtitle("") graphregion(color(white)) ///
	yline(0, lcolor(black) lwidth(vthin)) xscale(r(0.5 8.5) noline) yscale(r(-3 3) noline) ///
	xline(1.5 2.5 3.5 4.5 5.5 6.5 7.5, lpattern(dot) lcolor(black)) ///
	title("Panel D: Relative policy support on universalism, with controls", size(large)) ///
	ytitle("Regression coefficient: universalism", size(medium) height(6)) ysize(2.5) xsize(4.5)

graph export "$root/Output/fig_6d_universalism.eps", replace
	
restore

***********************************************************************************
* Coefficients from regressions of policy positions on universalism - NO CONTROLS
* WITH LIKERT SCALE QUESTIONS
***********************************************************************************
preserve
* Generate new observation for "All countries"
local new = _N + 1
set obs `new'
replace country = "Overall" if country == ""

local new = _N + 1
set obs `new'
replace country = "Overall2" if country == ""

foreach j in $policies{
	gen beta_`j' = .
	gen se_`j' = .
}

**********************************
* Running regressions
**********************************
foreach j in $policies{
	foreach i in $countries_western{
		qui reg s_`j'_rel_support universalism_overall if country=="`i'", ro
		mat bet = e(b)
		mat cov = e(V)
		
		replace beta_`j' = bet[1,1] if country == "`i'"
		replace se_`j' = sqrt(cov[1,1]) if country == "`i'"
	}
	
	* All countries	
	qui reg s_`j'_rel_support universalism_overall i.country_no, ro
	mat bet = e(b)
	mat cov = e(V)
		
	replace beta_`j' = bet[1,1] if country == "Overall" | country=="Overall2"
	replace se_`j' = sqrt(cov[1,1]) if country == "Overall" | country=="Overall2"
	
	gen bmin_`j' = beta_`j' - 1.96*se_`j'
	gen bmax_`j' = beta_`j' + 1.96*se_`j'
}

collapse (mean) beta_* se_* bmin_* bmax_*, by(country)
reshape long beta se bmin bmax, i(country) j(domain) string
replace domain = subinstr(domain, "_", "", 1)

* encoding in a specific order
gen domain_no = 1 if domain == "border"
replace domain_no = 2 if domain == "military"
replace domain_no = 3 if domain == "police"
replace domain_no = 4 if domain == "foreignaid"
replace domain_no = 5 if domain == "affaction"
replace domain_no = 6 if domain == "environment"
replace domain_no = 7 if domain == "health"
replace domain_no = 8 if domain == "welfare"

**********************************
* Figure 6: Expenditure Shares on Universalism (Panel C)
**********************************
gen domain_jitter = domain_no-0.5 if country=="Overall"
replace domain_jitter=domain_no+0.49 if country=="Overall2"

replace domain_jitter = domain_no-0.2 if country=="USA"
replace domain_jitter = domain_no-0.1 if country=="Australia"
replace domain_jitter = domain_no if country=="Germany"
replace domain_jitter = domain_no+0.1 if country=="France"
replace domain_jitter = domain_no+0.2 if country=="Sweden"

*Rename Overall2 to Overall for proper formatting of shaded areas
replace country="Overall" if country=="Overall2"
	
tw (scatter beta domain_jitter if country=="USA", msymbol(circle) msize(small) mcolor(blue)) ///
	(scatter beta domain_jitter if country=="Australia", msymbol(diamond) msize(small) mcolor(lavender)) ///
	(scatter beta domain_jitter if country=="Germany", msymbol(triangle) msize(small) mcolor(ebblue)) ///
	(scatter beta domain_jitter if country=="France", msymbol(square) msize(small) mcolor(navy)) ///
	(scatter beta domain_jitter if country=="Sweden", msymbol(plus) msize(small) mcolor(midgreen)) ///
	(line beta domain_jitter if country=="Overall" & domain=="affaction", lcolor(black%40) sort) ///
	(line beta domain_jitter if country=="Overall" & domain=="border", lcolor(black%40) sort) ///
	(line beta domain_jitter if country=="Overall" & domain=="environment", lcolor(black%40) sort) ///
	(line beta domain_jitter if country=="Overall" & domain=="foreignaid", lcolor(black%40) sort) ///
	(line beta domain_jitter if country=="Overall" & domain=="health", lcolor(black%40) sort) ///
	(line beta domain_jitter if country=="Overall" & domain=="military", lcolor(black%40) sort) ///
	(line beta domain_jitter if country=="Overall" & domain=="police", lcolor(black%40) sort) ///
	(line beta domain_jitter if country=="Overall" & domain=="welfare", lcolor(black%40) sort) ///
	(rarea bmin bmax domain_jitter if country=="Overall", sort lwidth(none) fcolor(gray%40)) ///
	(rcap bmin bmax domain_jitter if country=="USA", sort msize(vtiny) lcolor(blue)) ///
	(rcap bmin bmax domain_jitter if country=="Australia", sort msize(vtiny) lcolor(lavender)) ///
	(rcap bmin bmax domain_jitter if country=="Germany", sort msize(vtiny) lcolor(ebblue)) ///
	(rcap bmin bmax domain_jitter if country=="France", sort msize(vtiny) lcolor(navy)) ///
	(rcap bmin bmax domain_jitter if country=="Sweden", sort msize(vtiny) lcolor(midgreen)), ///
	xlabel(1 "Border" 2 "Military" 3 "Police" 4 `" "Foreign" "Aid" "' ///
	5 `" "Affirmative" "Action" "' 6 `" "Environ-" "ment" "' 7 `" "Health" "Care" "' 8 "Welfare", ///
	labsize(medium) notick) ///
	ylabel(-3(1)3, labsize(medium)) ///
	legend(order(1 "USA" 2 "Australia" 3 "Germany" 4 "France" 5 "Sweden" 6 "All countries") ///
	size(medium) cols(6) symxsize(8)) xtitle("") graphregion(color(white)) ///
	yline(0, lcolor(black) lwidth(vthin)) xscale(r(0.5 8.5) noline) yscale(r(-3.5 3.5) noline) ///
	xline(1.5 2.5 3.5 4.5 5.5 6.5 7.5, lpattern(dot) lcolor(black)) ///
	title("Panel C: Relative policy support on universalism", size(large)) ///
	ytitle("Regression coefficient: universalism", size(medium) height(6)) ysize(2.5) xsize(4.5)

graph export "$root/Output/fig_6c_universalism.eps", replace
	
restore
