* FIGURES THAT PLOT REGRESSION COEFFICIENTS
do "$root/Analyses/aux/set_globals"
use "$root/Data/survey_analysis_final.dta", clear

graph drop _all

***********************************************************************************
* Figure 8: Comparing magnitudes of coefs from regressions of policy positions
* (expenditure shares) on universalism, left-right, and income index
***********************************************************************************
preserve

drop if inlist(country, "Korea", "Brazil")

**********************************
* Running regressions
**********************************
rename s_universalism_overall s_universalism

foreach j in $policies{
	foreach i in universalism left_right income_index {
		
		gen beta_`j'_`i' = .
		gen se_`j'_`i' = .
		
		qui reg s_`j'_portion s_`i' i.country_no, ro
		mat bet = e(b)
		mat cov = e(V)
		
		replace beta_`j'_`i' = bet[1,1]
		replace se_`j'_`i' = sqrt(cov[1,1])
		
		gen bmin_`j'_`i' = beta_`j'_`i' - 1.96*se_`j'_`i'
		gen bmax_`j'_`i' = beta_`j'_`i' + 1.96*se_`j'_`i'
		
	}
}

collapse (mean) beta_* se_* bmin_* bmax_*

gen id=1
reshape long beta se bmin bmax, i(id) j(domain) string
gen predictor="left_right"
replace predictor="universalism" if strpos(domain,"universalism")>0
replace predictor="income_index" if strpos(domain,"income_index")>0

replace domain=subinstr(domain,"_left_right","",.)
replace domain=subinstr(domain,"_universalism","",.)
replace domain=subinstr(domain,"_income_index","",.)
replace domain = subinstr(domain, "_", "", 1)

* encoding in a specific order
gen domain_no = 1 if domain == "border"
replace domain_no = 2 if domain == "military"
replace domain_no = 3 if domain == "police"
replace domain_no = 4 if domain == "foreignaid"
replace domain_no = 5 if domain == "affaction"
replace domain_no = 6 if domain == "environment"
replace domain_no = 7 if domain == "health"
replace domain_no = 8 if domain == "welfare"

gen domain_jitter=domain_no
replace domain_jitter = domain_no-0.2 if predictor=="left_right"
replace domain_jitter = domain_no+0.2 if predictor=="income_index"

* Recode coefficients on income index to be negative for the right-wing policies,
* and positive for the left-wing policies, for comparability of mangnitudes
replace beta=(-1)*beta if predictor=="income_index"

replace bmin=beta-1.96*se if predictor=="income_index"
replace bmax=beta+1.96*se if predictor=="income_index"

**********************************
* Figure 8
**********************************
	
tw (scatter beta domain_jitter if predictor=="left_right", msymbol(circle) msize(small) mcolor(red)) ///
	(scatter beta domain_jitter if predictor=="universalism", msymbol(square) msize(small) mcolor(blue)) ///
	(scatter beta domain_jitter if predictor=="income_index", msymbol(triangle) msize(small) mcolor(green)) ///
	(rcap bmin bmax domain_jitter if predictor=="left_right", sort msize(vtiny) lcolor(red)) ///
	(rcap bmin bmax domain_jitter if predictor=="universalism", sort msize(vtiny) lcolor(blue)) ///
	(rcap bmin bmax domain_jitter if predictor=="income_index", sort msize(vtiny) lcolor(green)), ///
	xlabel(1 "Border" 2 "Military" 3 "Police" 4 `" "Foreign" "Aid" "' ///
	5 `" "Affirmative" "Action" "' 6 `" "Environ-" "ment" "' 7 `" "Health" "Care" "' 8 "Welfare", ///
	labsize(small) notick) ///
	ylabel(-0.3(0.1)0.3, labsize(small)) ///
	legend(order(1 "Left-Right Self-Assessment" 2 "Composite Universalism" 3 "Income") ///
	size(small) cols(6) symxsize(8)) xtitle("") graphregion(color(white)) ///
	yline(0, lcolor(black) lwidth(vthin)) xscale(r(0.5 8.5) noline) yscale(r(-0.3 0.3) noline) ///
	xline(1.5 2.5 3.5 4.5 5.5 6.5 7.5, lpattern(dot) lcolor(black)) ///
	title("Regression: Desired expenditure shares on predictor", size(medium)) ///
	ytitle("Regression coefficient: predictor", size(small) height(6))	

graph export "$root/Output/fig_8_magnitude.eps", replace
		
restore
