do "$root/Analyses/aux/set_globals"
use "$root/Data/survey_analysis_final.dta", clear

graph drop _all

preserve

drop if inlist(country, "Korea", "Brazil")

**********************************
* Running regressions
**********************************

* Generate dummy variables for regressions
gen female=(male==0)
gen female_univ=female*universalism_overall

gen racial_minority=((ethnicity=="African-American" | ethnicity=="American Indian or Alaska Native" | ethnicity=="Hispanic") & country=="USA")
gen racial_minority_univ=racial_minority*universalism_overall

* Label variables for table output
label var female "Female"
label var female_univ "Female x Universalism"

label var racial_minority "Racial minority"
label var racial_minority_univ "Racial minority x Universalism"

eststo clear

foreach i in s_hs_affaction_budget s_affaction_support {

	eststo:	reg `i' female universalism_overall female_univ $controls affaction_belief_benefit i.country_no, ro
	eststo:	reg `i' racial_minority universalism_overall racial_minority_univ $controls affaction_belief_benefit i.country_no if country=="USA", ro

}

esttab est1 est2 est3 est4 using "$root/Output/table_3_AA_preferences.tex", booktabs nonotes replace ///
 compress  label nomtitles rename() indicate("Country FE=*country*" "Controls=*$controls affaction_belief_benefit")  drop(_cons) ///
 order(universalism_overall female female_univ racial_minority racial_minority_univ) se(2) b(a2) r2(2)  star(* 0.10 ** 0.05 *** 0.01) ///
prehead("{\begin{tabular}{l*{8}{c}}\toprule\toprule &\multicolumn{4}{c}{\textit{Dependent variable:}}\\[.05cm] & \multicolumn{4}{c}{Z-scores of support for affirmative action:}\\[.2cm] & \multicolumn{2}{c}{Desired arsinh expenditure} & \multicolumn{2}{c}{Likert scale}\\\cmidrule(lr){2-3}\cmidrule(lr){4-5}") noomitted

restore
